.. _whatsnew-index:

######################
 What's New in Pylint
######################

High level descriptions of the most important changes between major Pylint versions.

.. toctree::
   :maxdepth: 1

   2.7.rst
   2.6.rst
   2.5.rst
   2.4.rst
   2.3.rst
   2.2.rst
   2.1.rst
   2.0.rst
   1.9.rst
   1.8.rst
   1.7.rst
   1.6.rst

The "Changelog" contains *all* nontrivial changes to Pylint for the current version.

.. toctree::
   :maxdepth: 2

   changelog.rst
